@@ -1,108 +1,108 @@
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
-    Namespace,
-    Deployment,
-    InstanceTypeUserSetting,
-    PodOSSOperationInfo,
-    InstanceInfo,
-    CommandSetting,
-    Ingress,
     Secret,
-    Condition,
-    ConfigMap,
-    OSSOperationInfo,
-    NodeInfo,
-    Service,
-    DNSRecord,
-    CommandResult,
     InstanceUserSetting,
-    ConfigMapUserSetting,
+    PodOSSOperationInfo,
+    NodeInfo,
+    InstanceTypeUserSetting,
+    OSSOperationInfo,
+    Condition,
     InstanceTypeWithStatus,
-    Pod,
+    ConfigMapUserSetting,
     ResourceOSSSetting,
+    NodeMeta,
+    ConfigMap,
+    Deployment,
+    DNSRecord,
     NodeUserSetting,
     SecretUserSetting,
-    NodeMeta
+    Ingress,
+    CommandSetting,
+    Namespace,
+    InstanceInfo,
+    Service,
+    CommandResult,
+    Pod
 )
 from ..domain.value_obj import (
-    Username,
-    NodeLabel,
+    InstanceTypeStatusCategory,
+    TimeInterval,
+    ServiceType,
+    Status,
+    InternetPayType,
+    DomainName,
+    Path,
+    Key,
+    Subdomain,
+    NodeStatus,
+    Version,
+    Hostname,
     Output,
-    InstanceTypeStatus,
-    ID,
-    RegionID,
-    Endpoint,
-    Usage,
+    Password,
     RecordID,
     Command,
-    BandWidth,
-    TimeInterval,
-    Type,
-    SecurityGroupID,
-    InstanceName,
-    Number,
-    Status,
-    Path,
-    Time,
-    DNSType,
-    Key,
-    Value,
-    InstanceType,
-    NodeType,
-    Weight,
-    DomainName,
-    Port,
     ZoneID,
-    DNSLine,
-    Hostname,
     GPUType,
+    Usage,
+    NodeLabel,
+    DNSLine,
+    BandWidth,
+    Weight,
+    Endpoint,
+    Name,
     NodeName,
     ImageID,
-    InstanceTypeStatusCategory,
-    Name,
-    ServiceType,
-    KeyType,
-    NodeStatus,
-    InternetPayType,
-    Version,
-    Bool,
-    Password,
+    Number,
     Size,
+    InstanceType,
+    DateTime,
     IP,
-    Info,
+    Port,
+    Value,
+    ID,
     InstanceID,
-    Price,
-    Subdomain,
+    DNSType,
+    Username,
+    KeyType,
+    InstanceName,
+    SecurityGroupID,
+    InstanceTypeStatus,
+    RegionID,
+    Bool,
     Data,
+    Price,
+    Type,
+    Time,
+    NodeType,
     Token,
-    PayType,
-    DateTime
+    Info,
+    PayType
 )
 from .do import (
+    OSSOperationInfoDO,
+    ResourceOSSSettingDO,
+    InstanceInfoDO,
+    InstanceUserSettingDO,
     NodeMetaDO,
-    SecretDO,
+    NodeInfoDO,
+    CommandResultDO,
+    ServiceDO,
+    ConfigMapDO,
     ConditionDO,
+    InstanceTypeUserSettingDO,
+    DNSRecordDO,
+    SecretUserSettingDO,
     ConfigMapUserSettingDO,
+    CommandSettingDO,
     NodeUserSettingDO,
     NamespaceDO,
-    DNSRecordDO,
-    PodDO,
-    NodeInfoDO,
-    InstanceUserSettingDO,
-    ResourceOSSSettingDO,
-    CommandResultDO,
     PodOSSOperationInfoDO,
-    CommandSettingDO,
-    SecretUserSettingDO,
-    InstanceInfoDO,
-    ConfigMapDO,
-    InstanceTypeWithStatusDO,
-    IngressDO,
+    SecretDO,
+    PodDO,
     DeploymentDO,
-    InstanceTypeUserSettingDO,
-    ServiceDO,
-    OSSOperationInfoDO
+    InstanceTypeWithStatusDO,
+    IngressDO
 )
 
 class ConditionConverter(Converter):
@@ -445,6 +445,7 @@ class NodeMetaConverter(Converter):
             run_time = Time(do.run_time),
             k3s_version = Version(do.k3s_version),
             label = NodeLabel(do.label),
+            private_ip = IP(do.private_ip),
             _life_time = Number(do._life_time)
         )
     def to_do(self, x: NodeMeta):
@@ -454,6 +455,7 @@ class NodeMetaConverter(Converter):
             run_time = None if x.run_time is None else x.run_time.get_value(),
             k3s_version = None if x.k3s_version is None else x.k3s_version.get_value(),
             label = None if x.label is None else x.label.get_value(),
+            private_ip = None if x.private_ip is None else x.private_ip.get_value(),
             _life_time = None if x._life_time is None else x._life_time.get_value()
         )
 
